==> wow_views-0.0.42.tar.gz: lib/components/view/danh_sach_nam_doc_2.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/interfaces/interface_action.dart';
import 'package:wowit/image_url.dart';
import 'package:wowit/methods.dart';
import 'package:wowit/widgets/wow_icon.dart';
import 'package:wowit/widgets/wow_image.dart';

class DanhSachNamDoc2 {
  Widget getMainView(Map<String, dynamic> data, String tableName) {
    var dsSuKien = Methods.getList(data['data'], tableName);
    var dsAction = Methods.getList(data, 'dsAction');
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    return ListView.builder(
      itemBuilder: (context, index) {
        return InkWell(
          onTap: () {
            if (kDebugMode) {
              print('onTap item ds nam doc 2 - ID:3');
            }
            iAction.actionCompoment(3, dsAction,
                idData: Methods.getInt(dsSuKien[index], 'ID', defaultValue: 0),
                params: {
                  '@id': Methods.getInt(dsSuKien[index], 'ID', defaultValue: 0)
                });
          },
          onLongPress: () {
            if (kDebugMode) {
              print('onLongTap item ds nam doc 2');
            }
            // DynamicView.actionCompomentView(3, dsAction,idData: Methods.getInt(dsSuKien[index], 'ID'));
          },
          child: Card(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                _hinhAnh(dsSuKien[index]),
                Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Text(
                    Methods.getString(dsSuKien[index], 'title'),
                    maxLines: 1,
                    style: const TextStyle(
                      color: Colors.black,
                      fontWeight: FontWeight.normal,
                      fontSize: 16,
                    ),
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.only(bottom: 8, right: 8, left: 8),
                  child: _thoGian(
                    Methods.showDate(
                      Methods.getDateTime(dsSuKien[index], 'createDate')!,
                    ),
                  ),
                )
              ],
            ),
          ),
        );
      },
      itemCount: dsSuKien.length,
      physics: const NeverScrollableScrollPhysics(),
      shrinkWrap: true,
    );
  }

  Widget _hinhAnh(Map<String,Object> hinhAnh) {
    return ClipRRect(
      borderRadius: const BorderRadius.only(
        topRight: Radius.circular(5),
        topLeft: Radius.circular(5),
      ),
      child: WowImage(
        hinhAnh,
        height: 200,
        width: Get.width,
      ),
    );
  }

  Widget _thoGian(String createDate) {
    return Row(
      children: [
        WowIcon(
          Methods.getURL(
            ImageByID.getUrlImage(2206),
          ),
          size: 20,
        ),
        const SizedBox(
          width: 8,
        ),
        Text(
          createDate,
          style: const TextStyle(
            color: Color(0xff6B6B6B),
            fontWeight: FontWeight.normal,
            fontSize: 16,
          ),
        )
      ],
    );
  }
}

==> wow_views-0.0.46.tar.gz: lib/components/view/danh_sach_nam_doc_2.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/interfaces/interface_action.dart';
import 'package:wowit/image_url.dart';
import 'package:wowit/methods.dart';
import 'package:wowit/widgets/wow_icon.dart';
import 'package:wowit/widgets/wow_image.dart';

class DanhSachNamDoc2 {
  Widget getMainView(Map<String, dynamic> data, String tableName) {
    var dsSuKien = Methods.getList(data['data'], tableName);
    var dsAction = Methods.getList(data, 'dsAction');
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    return ListView.builder(
      itemBuilder: (context, index) {
        return InkWell(
          onTap: () {
            if (kDebugMode) {
              print('onTap item ds nam doc 2 - ID:3');
            }
            iAction.actionCompoment(3, dsAction,
                idData: Methods.getInt(dsSuKien[index], 'ID', defaultValue: 0),
                params: {
                  '@id': Methods.getInt(dsSuKien[index], 'ID', defaultValue: 0)
                });
          },
          onLongPress: () {
            if (kDebugMode) {
              print('onLongTap item ds nam doc 2');
            }
            // DynamicView.actionCompomentView(3, dsAction,idData: Methods.getInt(dsSuKien[index], 'ID'));
          },
          child: Card(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                _hinhAnh(dsSuKien[index]),
                Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Text(
                    Methods.getString(dsSuKien[index], 'title'),
                    maxLines: 1,
                    style: const TextStyle(
                      color: Colors.black,
                      fontWeight: FontWeight.normal,
                      fontSize: 16,
                    ),
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.only(bottom: 8, right: 8, left: 8),
                  child: _thoGian(
                    Methods.showDate(
                      Methods.getDateTime(dsSuKien[index], 'createDate')!,
                    ),
                  ),
                )
              ],
            ),
          ),
        );
      },
      itemCount: dsSuKien.length,
      physics: const NeverScrollableScrollPhysics(),
      shrinkWrap: true,
    );
  }

  Widget _hinhAnh(Map<String, Object?> hinhAnh) {
    return ClipRRect(
      borderRadius: const BorderRadius.only(
        topRight: Radius.circular(5),
        topLeft: Radius.circular(5),
      ),
      child: WowImage(
        hinhAnh,
        height: 200,
        width: Get.width,
      ),
    );
  }

  Widget _thoGian(String createDate) {
    return Row(
      children: [
        WowIcon(
          Methods.getURL(
            ImageByID.getUrlImage(2206),
          ),
          size: 20,
        ),
        const SizedBox(
          width: 8,
        ),
        Text(
          createDate,
          style: const TextStyle(
            color: Color(0xff6B6B6B),
            fontWeight: FontWeight.normal,
            fontSize: 16,
          ),
        )
      ],
    );
  }
}
